@@ -1,5 +1,6 @@
-/* Copyright (C) 2000, 2001 Axel von Engeln <engeln@uni-bremen.de>
-                            Stefan Buehler  <sbuehler@uni-bremen.de>
+/* Copyright (C) 2000-2008
+   Axel von Engeln <engeln@uni-bremen.de>
+   Stefan Buehler  <sbuehler@ltu.se>
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -24,11 +25,13 @@
   function define_lineshape_data which sets the lineshape lookup
   data. 
 
+  This is the file from arts-1-0, back-ported to arts-1-1.
+
   \author Stefan Buehler
   \date   2000-08-21
 */
 
-#include <math.h>
+#include <cmath>
 #include "arts.h"
 #include "matpackI.h"
 #include "array.h"
@@ -45,8 +48,8 @@
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter. (Not used.)
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     \throw  runtime_error This exception is always thrown when the
                           function is called.  
@@ -54,13 +57,13 @@
     \date   2001-01-16 
     \author Stefan Buehler 
 */
-void lineshape_no_shape(  Vector&       /* ls */,
-                          Vector&       /* X */,
-                          Numeric       /* f0 */,
-                          Numeric       /* gamma */,
-                          Numeric       /* sigma */,
-                          VectorView    /* f_mono */,
-                          const Index   /* nf */)
+void lineshape_no_shape(  Vector&       ls _U_,
+                          Vector&       X _U_,
+                          Numeric       f0 _U_,
+                          Numeric       gamma _U_,
+                          Numeric       sigma _U_,
+                          VectorView    f_grid _U_,
+                          const Index   nf _U_)
 {
   // This function should never be called so throw an error here: 
   throw runtime_error("The no_shape lineshape is only a placeholder, but you tried\n"
@@ -75,23 +78,23 @@ void lineshape_no_shape(  Vector&       /* ls */,
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter. (Not used.)
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     \author Stefan Buehler 
     \date 2000-06-16 */
 void lineshape_lorentz(Vector&       ls,
-                       Vector&       /* X */,
+                       Vector&       X _U_,
                        Numeric       f0,
                        Numeric       gamma,
-                       Numeric       /* sigma */,
-                       VectorView f_mono,
+                       Numeric       sigma _U_,
+                       VectorView f_grid,
                        const Index  nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // PI:
   extern const Numeric PI;
@@ -103,7 +106,7 @@ void lineshape_lorentz(Vector&       ls,
 
   for ( Index i=0; i<nf; ++i )
     {
-      ls[i] =  fac / ( (f_mono[i]-f0) * (f_mono[i]-f0) + gamma2 );
+      ls[i] =  fac / ( (f_grid[i]-f0) * (f_grid[i]-f0) + gamma2 );
     }
 }
 
@@ -114,27 +117,27 @@ void lineshape_lorentz(Vector&       ls,
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter. (Not used.)
     \param  sigma         The Doppler broadening parameter.
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     \author Axel von Engeln
     \date 2000-12-06 */
 void lineshape_doppler(Vector&       ls,
-                       Vector&       /* x */,
+                       Vector&       x _U_,
                        Numeric       f0,
-                       Numeric       /* gamma */,
+                       Numeric       gamma _U_,
                        Numeric       sigma,
-                       VectorView f_mono,
+                       VectorView f_grid,
                        const Index  nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // SQRT(PI):
   extern const Numeric PI;
-  static const Numeric sqrtPI = sqrt(PI);
+  const Numeric sqrtPI = sqrt(PI);
 
   //  assert( ls.nelem() == nf );
 
@@ -143,7 +146,7 @@ void lineshape_doppler(Vector&       ls,
   
   for ( Index i=0; i<nf ; ++i )
     {
-      ls[i] = fac * exp( - pow( f_mono[i]-f0, 2) / sigma2 );
+      ls[i] = fac * exp( - pow( f_grid[i]-f0, 2) / sigma2 );
     }
 }
 
@@ -158,7 +161,7 @@ long bfun6_(Numeric y, Numeric x)
   long int ret_val;
 
   /* Local variables */
-  static Numeric s;
+  Numeric s = 0;
 
   /* -------------------------------------------------------------------- */
   s = fabs(x) + y;
@@ -184,8 +187,8 @@ long bfun6_(Numeric y, Numeric x)
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter.
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     Original c function call and documention:
 
@@ -234,21 +237,21 @@ long bfun6_(Numeric y, Numeric x)
     
 
     \author Oliver Lemke and Axel von Engeln
-    \date 2000-09-27 */ 
-
+    \date 2000-09-27
+*/ 
 void lineshape_voigt_kuntz6(Vector&       ls,
                             Vector&       x,
                             Numeric       f0,
                             Numeric       gamma,
                             Numeric       sigma,
-                            VectorView f_mono,
+                            VectorView f_grid,
                             const Index  nf)
 
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
   
 
   // seems not necessary for Doppler correction
@@ -266,26 +269,30 @@ void lineshape_voigt_kuntz6(Vector&       ls,
 
   /* Initialized data */
 
-  static Numeric yps1 = -1.0;
-  static Numeric yps2 = -1.0;
-  static Numeric yps3 = -1.0;
-  static Numeric yps4 = -1.0;
+  Numeric yps1 = -1.0;
+  Numeric yps2 = -1.0;
+  Numeric yps3 = -1.0;
+  Numeric yps4 = -1.0;
 
   /* System generated locals */
   long int i__1, i__2;
   Numeric r__1;
 
   /* Local variables */
-  static long int bmin, lauf[16]        /* was [4][4] */, bmax;
-  static long int imin, imax, stack[80] /* was [20][4] */;
-  static Numeric a1, a2, a3, a4, a5, a6, a8, b8, c8, d8, e8, f8, g8, h8, a7, 
+  long int bmin = 0, lauf[16] = {0}        /* was [4][4] */, bmax;
+  long int imin = 0, imax = 0, stack[80] = {0} /* was [20][4] */;
+  Numeric a1, a2, a3, a4, a5, a6, a8, b8, c8, d8, e8, f8, g8, h8, a7, 
     b7, c7, d7, e7, f7, o8, p8, q8, r8, s8, t8, g7, h7, o7, p7, q7, 
     r7, s7, t7, b6, c6, d6, e6, b5, c5, d5, e5, b4, c4, d4, b3, c3, 
     d3, b1, y2;
-  static long int i2, i1;
-  static Numeric x2, b2, c1;
-  static long int stackp, imitte;
-  static Numeric ym2;
+  a1 = a2 = a3 = a4 = a5 = a6 = a8 = b8 = c8 = d8 = e8 = f8 = g8 = h8 = a7
+    = b7 = c7 = d7 = e7 = f7 = o8 = p8 = q8 = r8 = s8 = t8 = g7 = h7 = o7 = p7
+    = q7 = r7 = s7 = t7 = b6 = c6 = d6 = e6 = b5 = c5 = d5 = e5 = b4 = c4 = d4
+    = b3 = c3 = d3 = b1 = y2 = 0;
+  long int i2 = 0, i1 = 0;
+  Numeric x2 = 0, b2 = 0, c1 = 0;
+  long int stackp = 0, imitte = 0;
+  Numeric ym2 = 0;
 
 
   // variables needed in original c routine:
@@ -296,7 +303,7 @@ void lineshape_voigt_kuntz6(Vector&       ls,
   // frequency in units of Doppler 
   for (i1=0; i1< (int) nf; i1++)
     {
-      x[i1] = (f_mono[i1] - f0) / sigma;
+      x[i1] = (f_grid[i1] - f0) / sigma;
     }
 
   /* Parameter adjustments */
@@ -455,7 +462,7 @@ void lineshape_voigt_kuntz6(Vector&       ls,
     }
     ym2 = y * 2;
     for (i2 = 1; i2 <= 3; i2 += 2) {
-      i__1 = lauf[(i2 + 1 << 2) - 1];
+      i__1 = lauf[((i2 + 1) << 2) - 1];
       for (i1 = lauf[(i2 << 2) - 1]; i1 <= i__1; ++i1) {
         x2 = x[i1-1] * x[i1-1];
         ls[i1-1] = fac * (exp(y2 - x2) * cos(x[i1-1] * ym2) - (a7 + x2 *
@@ -498,7 +505,7 @@ void lineshape_voigt_kuntz6(Vector&       ls,
       e6 = y * (y * 5.f + 13.3988f) + 1.49645f;
     }
     for (i2 = 1; i2 <= 3; i2 += 2) {
-      i__1 = lauf[(i2 + 1 << 2) - 2];
+      i__1 = lauf[((i2 + 1) << 2) - 2];
       for (i1 = lauf[(i2 << 2) - 2]; i1 <= i__1; ++i1) {
         x2 = x[i1-1] * x[i1-1];
         ls[i1-1] = fac * (a5 + x2 * (b5 + x2 * (c5 + x2 * (d5 + x2 * 
@@ -524,7 +531,7 @@ void lineshape_voigt_kuntz6(Vector&       ls,
       d4 = y2 * 4.f - 6.f;
     }
     for (i2 = 1; i2 <= 3; i2 += 2) {
-      i__1 = lauf[(i2 + 1 << 2) - 3];
+      i__1 = lauf[((i2 + 1) << 2) - 3];
       for (i1 = lauf[(i2 << 2) - 3]; i1 <= i__1; ++i1) {
         x2 = x[i1-1] * x[i1-1];
         ls[i1-1] = fac * (a3 + x2 * (b3 + x2 * (c3 + x2 * d3))) / (a4 
@@ -546,7 +553,7 @@ void lineshape_voigt_kuntz6(Vector&       ls,
 
     c1 = fac * a1;
     for (i2 = 1; i2 <= 3; i2 += 2) {
-      i__1 = lauf[(i2 + 1 << 2) - 4];
+      i__1 = lauf[((i2 + 1) << 2) - 4];
       for (i1 = lauf[(i2 << 2) - 4]; i1 <= i__1; ++i1) {
         x2 = x[i1-1] * x[i1-1];
         b2 = b1 - x2;
@@ -567,7 +574,7 @@ long int bfun3_(Numeric y, Numeric x)
     long int ret_val;
 
     /* Local variables */
-    static Numeric x2, y2;
+    Numeric x2 = 0, y2 = 0;
 
 /* -------------------------------------------------------------------- */
     x2 = x * x;
@@ -600,8 +607,8 @@ long int bfun3_(Numeric y, Numeric x)
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter.
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
 
     Original c function call and documention:
@@ -657,14 +664,14 @@ void lineshape_voigt_kuntz3(Vector&       ls,
                             Numeric       f0,
                             Numeric       gamma,
                             Numeric       sigma,
-                            VectorView f_mono,
+                            VectorView f_grid,
                             const Index  nf)
 
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // seems not necessary for Doppler correction
   //    extern const Numeric SQRT_NAT_LOG_2;
@@ -680,27 +687,31 @@ void lineshape_voigt_kuntz3(Vector&       ls,
 
   /* Initialized data */
 
-  static Numeric yps0 = -1.0;
-  static Numeric yps1 = -1.0;
-  static Numeric yps2 = -1.0;
-  static Numeric yps3 = -1.0;
-  static Numeric yps4 = -1.0;
+  Numeric yps0 = -1.0;
+  Numeric yps1 = -1.0;
+  Numeric yps2 = -1.0;
+  Numeric yps3 = -1.0;
+  Numeric yps4 = -1.0;
 
   /* System generated locals */
   long i__1, i__2;
   Numeric r__1;
 
   /* Local variables */
-  static long bmin, lauf[20]    /* was [5][4] */, bmax, imin, imax;
-  static long stack[80] /* was [20][4] */;
-  static Numeric a0, a1, a2, a3, a4, a5, a6, a7, a8, b8, c8, d8, e8, f8, g8, 
+  long bmin = 0, lauf[20] = {0}    /* was [5][4] */, bmax, imin, imax;
+  long stack[80] = {0} /* was [20][4] */;
+  Numeric a0, a1, a2, a3, a4, a5, a6, a7, a8, b8, c8, d8, e8, f8, g8, 
     h8, b7, c7, d7, e7, f7, g7, o8, p8, q8, r8, s8, t8, h7, o7, p7, 
     q7, r7, s7, t7, b6, c6, d6, e6, b5, c5, d5, e5, b4, c4, d4, b3, 
     c3, d3, b1, y2;
-  static long i2, i1;
-  static Numeric x2, b2, b0, c1;
-  static long stackp, imitte;
-  static Numeric ym2;
+  a0 = a1 = a2 = a3 = a4 = a5 = a6 = a7 = a8 = b8 = c8 = d8 = e8 = f8 = g8
+    = h8 = b7 = c7 = d7 = e7 = f7 = g7 = o8 = p8 = q8 = r8 = s8 = t8 = h7 = o7
+    = p7 = q7 = r7 = s7 = t7 = b6 = c6 = d6 = e6 = b5 = c5 = d5 = e5 = b4 = c4
+    = d4 = b3 = c3 = d3 = b1 = y2 = 0;
+  long i2 = 0, i1 = 0;
+  Numeric x2 = 0, b2 = 0, b0 = 0, c1 = 0;
+  long stackp = 0, imitte = 0;
+  Numeric ym2 = 0;
 
   // variables needed in original c routine:
 
@@ -710,7 +721,7 @@ void lineshape_voigt_kuntz3(Vector&       ls,
   // frequency in units of Doppler 
   for (i1=0; i1< (int) nf; i1++)
     {
-      x[i1] = (f_mono[i1] - f0) / sigma;
+      x[i1] = (f_grid[i1] - f0) / sigma;
     }
 
 
@@ -945,7 +956,7 @@ long bfun4_(Numeric y, Numeric x)
     long ret_val;
 
     /* Local variables */
-    static Numeric x2, y2;
+    Numeric x2 = 0, y2 = 0;
 
     x2 = x * x;
     y2 = y * y;
@@ -975,8 +986,8 @@ long bfun4_(Numeric y, Numeric x)
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter. (Not used.)
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     Original c function call and documention:
 
@@ -1031,13 +1042,13 @@ void lineshape_voigt_kuntz4(Vector&       ls,
                             Numeric       f0,
                             Numeric       gamma,
                             Numeric       sigma,
-                            VectorView f_mono,
+                            VectorView f_grid,
                             const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // seems not necessary for Doppler correction
   //    extern const Numeric SQRT_NAT_LOG_2;
@@ -1054,27 +1065,31 @@ void lineshape_voigt_kuntz4(Vector&       ls,
 
     /* Initialized data */
 
-    static float yps0 = -1.f;
-    static float yps1 = -1.f;
-    static float yps2 = -1.f;
-    static float yps3 = -1.f;
-    static float yps4 = -1.f;
+    float yps0 = -1.f;
+    float yps1 = -1.f;
+    float yps2 = -1.f;
+    float yps3 = -1.f;
+    float yps4 = -1.f;
 
     /* System generated locals */
     long i__1, i__2;
     float r__1;
 
     /* Local variables */
-    static long bmin, lauf[20]  /* was [5][4] */, bmax, imin, imax;
-    static long stack[80]       /* was [20][4] */;
-    static Numeric a0, a1, a2, a3, a4, a5, a6, a7, a8, b8, c8, d8, e8, f8, g8, 
+    long bmin = 0, lauf[20] = {0}  /* was [5][4] */, bmax, imin, imax;
+    long stack[80] = {0}       /* was [20][4] */;
+    Numeric a0, a1, a2, a3, a4, a5, a6, a7, a8, b8, c8, d8, e8, f8, g8, 
             h8, b7, c7, d7, e7, f7, g7, o8, p8, q8, r8, s8, t8, h7, o7, p7, 
             q7, r7, s7, t7, b6, c6, d6, e6, b5, c5, d5, e5, b4, c4, d4, b3, 
             c3, d3, b1, y2;
-    static long i2, i1;
-    static Numeric x2, b2, b0, c1;
-    static long stackp, imitte;
-    static Numeric ym2;
+    a0 = a1 = a2 = a3 = a4 = a5 = a6 = a7 = a8 = b8 = c8 = d8 = e8 = f8 = g8
+      = h8 = b7 = c7 = d7 = e7 = f7 = g7 = o8 = p8 = q8 = r8 = s8 = t8 = h7
+      = o7 = p7 = q7 = r7 = s7 = t7 = b6 = c6 = d6 = e6 = b5 = c5 = d5 = e5
+      = b4 = c4 = d4 = b3 = c3 = d3 = b1 = y2 = 0;
+    long i2 = 0, i1 = 0;
+    Numeric x2 = 0, b2 = 0, b0 = 0, c1 = 0;
+    long stackp = 0, imitte = 0;
+    Numeric ym2 = 0;
 
   // variables needed in original c routine:
 
@@ -1084,7 +1099,7 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   // frequency in units of Doppler 
   for (i1=0; i1< (int) nf; i1++)
     {
-      x[i1] = (f_mono[i1] - f0) / sigma;
+      x[i1] = (f_grid[i1] - f0) / sigma;
     }
 
 
@@ -1157,8 +1172,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   /* ---- Region 4 */
   /* -------------------------------------------------------------------- */
   if (lauf[9] >= lauf[4] || lauf[19] >= lauf[14]) {
-    if ((r__1 = y - yps4, fabs(r__1)) > 1e-8f) {
-      yps4 = y;
+    if ((r__1 = (float)(y - yps4), fabs(r__1)) > 1e-8f) {
+      yps4 = (float)y;
       a7 = y * (y2 * (y2 * (y2 * (y2 * (y2 * (y2 * (y2 * (y2 * (y2 * (
                     y2 * (y2 * (y2 * (2.35944f - y2 * .56419f) - 72.9359f) + 
                     571.687f) - 5860.68f) + 40649.2f) - 320772.f) + 1684100.f)
@@ -1261,8 +1276,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   /* ---- Region 3 */
   /* -------------------------------------------------------------------- */
   if (lauf[8] >= lauf[3] || lauf[18] >= lauf[13]) {
-    if ((r__1 = y - yps3, fabs(r__1)) > 1e-8f) {
-      yps3 = y;
+    if ((r__1 = (float)(y - yps3), fabs(r__1)) > 1e-8f) {
+      yps3 = (float)y;
       a5 = y * (y * (y * (y * (y * (y * (y * (y * (y * 
                     .564224f + 7.55895f) + 49.5213f) + 204.501f) + 581.746f) 
                     + 1174.8f) + 1678.33f) + 1629.76f) + 973.778f) + 272.102f;
@@ -1300,8 +1315,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   /* ---- Region 2 */
   /* -------------------------------------------------------------------- */
   if (lauf[7] >= lauf[2] || lauf[17] >= lauf[12]) {
-    if ((r__1 = y - yps2, fabs(r__1)) > 1e-8f) {
-      yps2 = y;
+    if ((r__1 = (float)(y - yps2), fabs(r__1)) > 1e-8f) {
+      yps2 = (float)y;
       a3 = y * (y2 * (y2 * (y2 * .56419f + 3.10304f) + 4.65456f) + 
                     1.05786f);
       b3 = y * (y2 * (y2 * 1.69257f + .56419f) + 2.962f);
@@ -1325,8 +1340,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   /* ---- Region 1 */
   /* -------------------------------------------------------------------- */
   if (lauf[6] >= lauf[1] || lauf[16] >= lauf[11]) {
-    if ((r__1 = y - yps1, fabs(r__1)) > 1e-8f) {
-      yps1 = y;
+    if ((r__1 = (float)(y - yps1), fabs(r__1)) > 1e-8f) {
+      yps1 = (float)y;
       a1 = y * .5641896f;
       b1 = y2 + .5f;
       a2 = y2 * 4;
@@ -1347,8 +1362,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
   /* -------------------------------------------------------------------- */
  L8:
   if (lauf[5] >= lauf[0] || lauf[15] >= lauf[10]) {
-    if ((r__1 = y - yps0, fabs(r__1)) > 1e-8f) {
-      yps0 = y;
+    if ((r__1 = (float)(y - yps0), fabs(r__1)) > 1e-8f) {
+      yps0 = (float)y;
       a0 = y * .5641896f;
     }
 
@@ -1373,8 +1388,8 @@ void lineshape_voigt_kuntz4(Vector&       ls,
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter.
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
 
     Original ife function call and documention:
@@ -1416,14 +1431,14 @@ void lineshape_voigt_drayson(Vector&       ls,
                              Numeric         f0,
                              Numeric       gamma,
                              Numeric       sigma,
-                             VectorView f_mono,
+                             VectorView f_grid,
                              const Index   nf)
 
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // seems not necessary for Doppler correction
   //    extern const Numeric SQRT_NAT_LOG_2;
@@ -1437,13 +1452,13 @@ void lineshape_voigt_drayson(Vector&       ls,
   // constant normalization factor for voigt
   Numeric fac = 1.0 / sigma * sqrt_invPI;
 
-      static Numeric B[22+1] = {0.,0.,.7093602e-7};
-      static Numeric RI[15+1];
+      Numeric B[22+1] = {0.,0.,.7093602e-7};
+      Numeric RI[15+1] = {0};
       const  Numeric XN[15+1] = {0.,10.,9.,8.,8.,7.,6.,5.,4.,3.,3.,3.,3.,3.,3.,3.};
       const  Numeric YN[15+1] = {0.,.6,.6,.6,.5,.4,.4,.3,.3,.3,.3,1.,.9,.8,.7,.7};
-      static Numeric D0[25+1], D1[25+1], D2[25+1], D3[25+1], D4[25+1];
-      static Numeric HN[25+1];
-      static Numeric H = .201;
+      Numeric D0[25+1] = {0}, D1[25+1] = {0}, D2[25+1] = {0}, D3[25+1] = {0}, D4[25+1] = {0};
+      Numeric HN[25+1] = {0};
+      Numeric H = .201;
       const  Numeric XX[3+1] = {0.,.5246476,1.65068,.7071068};
       const  Numeric HH[3+1] = {0.,.2562121,.2588268e-1,.2820948};
       const  Numeric NBY2[19+1] = {0.,9.5,9.,8.5,8.,7.5,7.,6.5
@@ -1453,10 +1468,10 @@ void lineshape_voigt_drayson(Vector&       ls,
           -.1933631e-3,.4899520e-3,-.1173267e-2,.2648762e-2,
           -.5623190e-2,.1119601e-1,-.2084976e-1,.3621573e-1,
           -.5851412e-1,.8770816e-1,-.121664,.15584,-.184,.2};
-      static Numeric CO;
+      Numeric CO = 0;
       Numeric U, V, UU, VV, Y2, DX;
       int I, J, K, MAX, MIN, N, i1;
-      static int TRU = 0;
+      int TRU = 0;
 
 
       // variables needed in original c routine:
@@ -1468,7 +1483,7 @@ void lineshape_voigt_drayson(Vector&       ls,
       // positive values
       for (i1=0; i1< (int) nf; i1++)
         {
-          x[i1] = fabs( (f_mono[i1] - f0) )/ sigma;
+          x[i1] = fabs( (f_grid[i1] - f0) )/ sigma;
         }
 
 
@@ -1563,8 +1578,8 @@ L104: for (K=0; K<(int) nf; K++)
   \param  f0            Line center frequency.
   \param  gamma         The pressure broadening parameter.
   \param  sigma         The Doppler broadening parameter.
-  \param  f_mono        The frequency grid.
-  \param  nf            Dimension of f_mono.
+  \param  f_grid        The frequency grid.
+  \param  nf            Dimension of f_grid.
 
   REFERENCE FOR EQUATIONS AND COEFFICIENTS:
   P.W. ROSENKRANZ, CHAP. 2 AND APPENDIX, IN ATMOSPHERIC REMOTE SENSING
@@ -1582,19 +1597,29 @@ void lineshape_rosenkranz_voigt_kuntz6(Vector&       ls,
                                        Numeric       f0,
                                        Numeric       gamma,
                                        Numeric       sigma,
-                                       VectorView f_mono,
+                                       VectorView f_grid,
                                        const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // seems not necessary for Doppler correction
   //    extern const Numeric SQRT_NAT_LOG_2;
 
   extern const Numeric PI;
 
+  // ARTS now has a global default of abs_h2o of -1, to flag that it
+  // is not set. This is passed down here as x[4] (aux[4]). We have to
+  // check here if this is positive, to make sure it has been set.
+  if (x[4] < -.99)
+    {
+      ostringstream os;
+      os << "You have to set abs_h2o if you want to use this lineshape.";
+      throw runtime_error( os.str() );
+    }
+
 
   // calculate the required stuff with the parameter of the x array:
   Numeric overlap;      // overlap correction
@@ -1643,7 +1668,7 @@ void lineshape_rosenkranz_voigt_kuntz6(Vector&       ls,
                              f0,
                              gamma_o2,
                              sigma,
-                             f_mono,
+                             f_grid,
                              nf);
     }
   else
@@ -1651,8 +1676,8 @@ void lineshape_rosenkranz_voigt_kuntz6(Vector&       ls,
       Numeric FD, FS, SF1, SF2;
       for (Index J=0; J<(Index) nf; J++)
         {
-          FD = f_mono[J] - f0;
-          FS = f_mono[J] + f0;
+          FD = f_grid[J] - f0;
+          FS = f_grid[J] + f0;
           SF1 = (gamma_o2 + FD*overlap) / (FD*FD + gamma_o2_2);
           SF2 = (gamma_o2 - FS*overlap) / (FS*FS + gamma_o2_2);
           ls[J] = (SF1 + SF2) / PI;
@@ -1671,8 +1696,8 @@ void lineshape_rosenkranz_voigt_kuntz6(Vector&       ls,
   \param  f0            Line center frequency.
   \param  gamma         The pressure broadening parameter.
   \param  sigma         The Doppler broadening parameter.
-  \param  f_mono        The frequency grid.
-  \param  nf            Dimension of f_mono.
+  \param  f_grid        The frequency grid.
+  \param  nf            Dimension of f_grid.
 
   REFERENCE FOR EQUATIONS AND COEFFICIENTS:
   P.W. ROSENKRANZ, CHAP. 2 AND APPENDIX, IN ATMOSPHERIC REMOTE SENSING
@@ -1690,13 +1715,13 @@ void lineshape_rosenkranz_voigt_drayson(Vector&       ls,
                                         Numeric      f0,
                                         Numeric       gamma,
                                         Numeric       sigma,
-                                        VectorView f_mono,
+                                        VectorView f_grid,
                                         const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // seems not necessary for Doppler correction
   //    extern const Numeric SQRT_NAT_LOG_2;
@@ -1750,7 +1775,7 @@ void lineshape_rosenkranz_voigt_drayson(Vector&       ls,
                               f0,
                               gamma_o2,
                               sigma,
-                              f_mono,
+                              f_grid,
                               nf);
 
       // the controlfile uses generally a (f/f0)^2 factor for the
@@ -1763,7 +1788,7 @@ void lineshape_rosenkranz_voigt_drayson(Vector&       ls,
       Numeric f0_2 = f0 * f0;
       for (Index J=0; J<(Index) nf; J++)
         {
-          ls[J] *= f0_2 / (f_mono[J] * f_mono[J]);
+          ls[J] *= f0_2 / (f_grid[J] * f_grid[J]);
         }
     }
   else
@@ -1771,8 +1796,8 @@ void lineshape_rosenkranz_voigt_drayson(Vector&       ls,
       Numeric FD, FS, SF1, SF2;
       for (Index J=0; J<(Index) nf; J++)
         {
-          FD = f_mono[J] - f0;
-          FS = f_mono[J] + f0;
+          FD = f_grid[J] - f0;
+          FS = f_grid[J] + f0;
           SF1 = (gamma_o2 + FD*overlap) / (FD*FD + gamma_o2_2);
           SF2 = (gamma_o2 - FS*overlap) / (FS*FS + gamma_o2_2);
           ls[J] = (SF1 + SF2) / PI;
@@ -1838,21 +1863,21 @@ void chi_cousin(
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter. (Not used.)
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     \author Patrick Eriksson 
     \date 2000-09-04 */
 void lineshape_CO2_lorentz(
             Vector&   ls,
-            Vector&   /* X */,
+            Vector&   X _U_,
             Numeric   f0,
             Numeric   gamma,
-            Numeric   /* sigma */,
-      VectorView      f_mono,
+            Numeric   sigma _U_,
+      VectorView      f_grid,
       const Index     nf )
 {
-  assert( f_mono.nelem() == nf );
+  assert( f_grid.nelem() == nf );
 
   // PI:
   extern const Numeric PI;
@@ -1864,7 +1889,7 @@ void lineshape_CO2_lorentz(
   for ( Index i=0; i<nf; ++i )
     {
       // f-f0
-      const Numeric df = f_mono[i] - f0;
+      const Numeric df = f_grid[i] - f0;
 
       // The chi factor
       Numeric chi;
@@ -1884,8 +1909,8 @@ void lineshape_CO2_lorentz(
     \param  f0            Line center frequency.
     \param  gamma         The pressure broadening parameter.
     \param  sigma         The Doppler broadening parameter. (Not used.)
-    \param  f_mono        The frequency grid.
-    \param  nf            Dimension of f_mono.
+    \param  f_grid        The frequency grid.
+    \param  nf            Dimension of f_grid.
 
     \author Patrick Eriksson 
     \date 2000-09-04 */
@@ -1895,15 +1920,15 @@ void lineshape_CO2_drayson(
             Numeric   f0,
             Numeric   gamma,
             Numeric   sigma,
-      VectorView      f_mono,
+      VectorView      f_grid,
       const Index     nf )
 {
-  lineshape_voigt_drayson(  ls, X, f0, gamma, sigma, f_mono, nf );
+  lineshape_voigt_drayson(  ls, X, f0, gamma, sigma, f_grid, nf );
 
   for ( Index i=0; i<nf; ++i )
     {
       // f-f0
-      const Numeric df = f_mono[i] - f0;
+      const Numeric df = f_grid[i] - f0;
 
       // The chi factor
       Numeric chi;
@@ -1928,21 +1953,24 @@ void lineshape_CO2_drayson(
 
     \retval fac    Normalization factor to the lineshape function.
     \param  f0     Line center frequency.
-    \param  f_mono The frequency grid.
+    \param  f_grid The frequency grid.
     \param  T      Temperature (unused here)
-    \param  nf     Dimension of f_mono.
+    \param  nf     Dimension of f_grid.
 
     \author Axel von Engeln 30.11.2000 */
 void lineshape_norm_no_norm(Vector&       fac,
-                            Numeric       /* f0 */,
-                            VectorView    f_mono,
-                            const Numeric /* T */,
+                            Numeric       f0 _U_,
+                            VectorView    f_grid,
+                            const Numeric T _U_,
                             const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
-  // correct: 
-  assert( nf==f_mono.nelem() );
+  // correct:
+  if (f_grid.nelem()>-1)
+    {
+      assert( nf==f_grid.nelem() );
+    }
 
   for ( Index i=0; i<nf; ++i )
     {
@@ -1956,25 +1984,25 @@ void lineshape_norm_no_norm(Vector&       fac,
 
     \retval fac    Normalization factor to the lineshape function.
     \param  f0     Line center frequency.
-    \param  f_mono The frequency grid.
-    \param  T      Temperature (unused here)
-    \param  nf     Dimension of f_mono.
+    \param  f_grid The frequency grid.
+    \param  T      (unused here)
+    \param  nf     Dimension of f_grid.
 
     \author Axel von Engeln 30.11.2000 */
 void lineshape_norm_linear(Vector&       fac,
                            Numeric       f0,
-                           VectorView    f_mono,
-                           const Numeric /* T */,
+                           VectorView    f_grid,
+                           const Numeric T _U_,
                            const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   for ( Index i=0; i<nf; ++i )
     {
-      fac[i] = f_mono[i] / f0;
+      fac[i] = f_grid[i] / f0;
     }
 }
 
@@ -1982,29 +2010,29 @@ void lineshape_norm_linear(Vector&       fac,
 
     \retval fac    Normalization factor to the lineshape function.
     \param  f0     Line center frequency.
-    \param  f_mono The frequency grid.
+    \param  f_grid The frequency grid.
     \param  T      Temperature (unused here)
-    \param  nf     Dimension of f_mono.
+    \param  nf     Dimension of f_grid.
 
 
     \author Axel von Engeln 30.11.2000 */
 void lineshape_norm_quadratic(Vector&       fac,
                               Numeric       f0,
-                              VectorView    f_mono,
-                              const Numeric /* T */,
+                              VectorView    f_grid,
+                              const Numeric T _U_,
                               const Index   nf)
 {
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // don't do this for the whole loop
   Numeric f0_2 = f0 * f0;
 
   for ( Index i=0; i<nf; ++i )
     {
-      fac[i] = (f_mono[i] * f_mono[i]) / f0_2;
+      fac[i] = (f_grid[i] * f_grid[i]) / f0_2;
     }
 }
 
@@ -2018,15 +2046,15 @@ void lineshape_norm_quadratic(Vector&       fac,
 
     \retval fac    Normalization factor to the lineshape function.
     \param  f0     Line center frequency.
-    \param  f_mono The frequency grid.
+    \param  f_grid The frequency grid.
     \param  T      Temperature
-    \param  nf     Dimension of f_mono.
+    \param  nf     Dimension of f_grid.
 
 
     \author Axel von Engeln 2003-07-28 */
 void lineshape_norm_VVH(Vector&       fac,
                         Numeric       f0,
-                        VectorView    f_mono,
+                        VectorView    f_grid,
                         const Numeric T,
                         const Index   nf)
 {
@@ -2036,7 +2064,7 @@ void lineshape_norm_VVH(Vector&       fac,
   // FIXME: nf is actually redundant. Could be thrown out in the
   // future. For now, let's do an assertion that at least it is
   // correct: 
-  assert( nf==f_mono.nelem() );
+  assert( nf==f_grid.nelem() );
 
   // 2kT is constant for the loop
   Numeric kT = 2.0 * BOLTZMAN_CONST * T;
@@ -2046,7 +2074,7 @@ void lineshape_norm_VVH(Vector&       fac,
 
   for ( Index i=0; i<nf; ++i )
     {
-      fac[i] = f_mono[i] * tanh( PLANCK_CONST * f_mono[i] / kT ) /
+      fac[i] = f_grid[i] * tanh( PLANCK_CONST * f_grid[i] / kT ) /
         denom;
     }
 }
@@ -2169,12 +2197,6 @@ void define_lineshape_norm_data()
       "No normalization of the lineshape.",
       lineshape_norm_no_norm));
 
-  lineshape_norm_data.push_back
-    (LineshapeNormRecord
-     ("linear",
-      "Linear normalization of the lineshape with f/f0.",
-      lineshape_norm_linear));
-
   lineshape_norm_data.push_back
     (LineshapeNormRecord
      ("quadratic",
